# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .batch_number import BatchNumber
from .bill_data import BillData
from .category import Category
from .created_at import CreatedAt
from .deposit_date import DepositDate
from .expected_deposit_date import ExpectedDepositDate
from .external_paypoint_id import ExternalPaypointId
from .maskedaccount import Maskedaccount
from .netamountnullable import Netamountnullable
from .order_id import OrderId
from .org_parent_name import OrgParentName
from .query_payment_data import QueryPaymentData
from .query_response_data import QueryResponseData
from .query_transaction_events import QueryTransactionEvents
from .query_transaction_payor_data import QueryTransactionPayorData
from .settlement_status import SettlementStatus
from .source import Source
from .trans_status import TransStatus
from .transaction_time import TransactionTime


class QueryResponseSettlementsRecordsItem(UniversalBaseModel):
    """
    Examples
    --------
    import datetime

    from payabli import (
        PaymentCategories,
        PaymentDetail,
        QueryPaymentData,
        QueryResponseData,
        QueryResponseSettlementsRecordsItem,
        QueryTransactionEvents,
        QueryTransactionPayorData,
        SplitFundingContent,
    )

    QueryResponseSettlementsRecordsItem(
        batch_amount=32.0,
        batch_number="batch-100-20-2024",
        category="auth",
        created_at=datetime.datetime.fromisoformat(
            "2024-11-19 15:58:01+00:00",
        ),
        customer=QueryTransactionPayorData(
            billing_address_1="100 Golden Ridge Drive",
            billing_address_2="STE 100",
            billing_city="Mendota",
            billing_country="US",
            billing_email="lydia@example.com",
            billing_phone="+12345678",
            billing_state="VA",
            billing_zip="20147",
            customer_id=2707,
            customer_number="901102",
            customer_status=1,
            first_name="Lydia",
            last_name="Marshall",
        ),
        expected_deposit_date=datetime.datetime.fromisoformat(
            "2024-11-22 00:00:00+00:00",
        ),
        gateway_trans_id="TRN_XXXXX",
        id=25048,
        is_hold=0,
        masked_account="1XXXXXX5678",
        method="ach",
        net_amount=2.0,
        operation="Sale",
        order_id="",
        parent_org_name="Pilgrim Planner",
        payment_data=QueryPaymentData(
            account_type="Checking",
            holder_name="Lydia Marshall",
            masked_account="1XXXXXX5678",
            payment_details=PaymentDetail(
                categories=[
                    PaymentCategories(
                        amount=1000.0,
                        label="Deposit",
                    )
                ],
                currency="USD",
                service_fee=0.0,
                split_funding=[SplitFundingContent()],
                total_amount=2.0,
            ),
        ),
        payment_trans_id="245-9e4072eef77e45979ea0e49f680000X",
        payment_trans_status=1,
        paypoint_dbaname="Gruzya Adventure Outfitters, LLC",
        paypoint_entryname="7f1a3816XX",
        paypoint_legalname="Gruzya Adventure Outfitters, LLC",
        response_data=QueryResponseData(
            authcode=" ",
            avsresponse=" ",
            avsresponse_text="",
            cvvresponse=" ",
            cvvresponse_text=" ",
            emv_auth_response_data=" ",
            response="Success",
            response_code="100",
            response_code_text="Transaction was approved.",
            responsetext="CAPTURED",
            result_code="A0000",
            result_code_text="Approved",
            transactionid="TRN_xwCAjQorWAYX1nAhAoHZVfN8iYHbI0",
        ),
        schedule_reference=0,
        settled_amount=0.5,
        settlement_date=datetime.datetime.fromisoformat(
            "2024-11-20 00:00:00+00:00",
        ),
        source="api",
        status=1,
        transaction_events=[
            QueryTransactionEvents(
                event_time=datetime.datetime.fromisoformat(
                    "2024-11-19 15:57:40+00:00",
                ),
                trans_event="Created",
            ),
            QueryTransactionEvents(
                event_data={
                    "account_id": "TRA_XXXXX",
                    "account_name": "123456",
                    "action": {
                        "app_id": "XXXXX",
                        "app_name": "PayAbli",
                        "id": "ACT_XXXXX",
                        "result_code": "SUCCESS",
                        "time_created": "2024-11-19T20:58:01.583Z",
                        "type": "AUTHORIZE",
                    },
                    "amount": "200",
                    "batch_id": "",
                    "capture_mode": "AUTO",
                    "channel": "CNP",
                    "country": "US",
                    "currency": "USD",
                    "fees": {"amount": "0", "rate": "0.00", "total_amount": "0"},
                    "id": "TRN_XXXXX",
                    "merchant_amount": "200",
                    "merchant_id": "MER_XXXXX",
                    "merchant_name": "Henriette97",
                    "order": {"reference": ""},
                    "payment_method": {
                        "bank_transfer": {
                            "account_type": "CHECKING",
                            "bank": {"name": ""},
                            "masked_account_number_last4": "XXXX5678",
                        },
                        "entry_mode": "ECOM",
                        "message": "Success",
                        "narrative": "Lydia Marshall",
                        "result": "00",
                    },
                    "reference": "245-XXXXX",
                    "status": "CAPTURED",
                    "time_created": "2024-11-19T20:58:01.583Z",
                    "type": "SALE",
                },
                event_time=datetime.datetime.fromisoformat(
                    "2024-11-19 20:58:01+00:00",
                ),
                trans_event="Approved",
            ),
            QueryTransactionEvents(
                event_time=datetime.datetime.fromisoformat(
                    "2024-11-20 03:05:10+00:00",
                ),
                trans_event="ClosedBatch",
            ),
        ],
        transaction_time=datetime.datetime.fromisoformat(
            "2024-11-19 15:58:01+00:00",
        ),
        trans_method="ach",
        type="credit",
    )
    """

    batch_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchAmount"),
        pydantic.Field(alias="BatchAmount", description="The batch amount."),
    ] = None
    batch_number: typing_extensions.Annotated[
        typing.Optional[BatchNumber], FieldMetadata(alias="BatchNumber"), pydantic.Field(alias="BatchNumber")
    ] = None
    category: typing_extensions.Annotated[
        typing.Optional[Category], FieldMetadata(alias="Category"), pydantic.Field(alias="Category")
    ] = None
    created_at: typing_extensions.Annotated[
        typing.Optional[CreatedAt], FieldMetadata(alias="CreatedAt"), pydantic.Field(alias="CreatedAt")
    ] = None
    customer: typing_extensions.Annotated[
        typing.Optional[QueryTransactionPayorData], FieldMetadata(alias="Customer"), pydantic.Field(alias="Customer")
    ] = None
    deposit_date: typing_extensions.Annotated[
        typing.Optional[DepositDate], FieldMetadata(alias="DepositDate"), pydantic.Field(alias="DepositDate")
    ] = None
    expected_deposit_date: typing_extensions.Annotated[
        typing.Optional[ExpectedDepositDate],
        FieldMetadata(alias="ExpectedDepositDate"),
        pydantic.Field(alias="ExpectedDepositDate"),
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    gateway_trans_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="GatewayTransId"),
        pydantic.Field(alias="GatewayTransId", description="Internal identifier used for processing."),
    ] = None
    id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="Id"), pydantic.Field(alias="Id")] = None
    invoice_data: typing_extensions.Annotated[
        typing.Optional[BillData], FieldMetadata(alias="invoiceData"), pydantic.Field(alias="invoiceData")
    ] = None
    is_hold: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="isHold"),
        pydantic.Field(
            alias="isHold",
            description="\nDescribes whether the transaction is being held or not.\n\n1 - Transaction is held\n\n0 - Transaction isn't being held",
        ),
    ] = None
    masked_account: typing_extensions.Annotated[
        typing.Optional[Maskedaccount], FieldMetadata(alias="MaskedAccount"), pydantic.Field(alias="MaskedAccount")
    ] = None
    method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Method"),
        pydantic.Field(alias="Method", description="The payment method."),
    ] = None
    net_amount: typing_extensions.Annotated[
        typing.Optional[Netamountnullable],
        FieldMetadata(alias="NetAmount"),
        pydantic.Field(alias="NetAmount", description="Net amount paid."),
    ] = None
    operation: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Operation"),
        pydantic.Field(alias="Operation", description="The operation performed."),
    ] = None
    order_id: typing_extensions.Annotated[
        typing.Optional[OrderId], FieldMetadata(alias="OrderId"), pydantic.Field(alias="OrderId")
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    payment_data: typing_extensions.Annotated[
        typing.Optional[QueryPaymentData], FieldMetadata(alias="PaymentData"), pydantic.Field(alias="PaymentData")
    ] = None
    payment_trans_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentTransId"),
        pydantic.Field(alias="PaymentTransId", description="The transaction ID for the payment."),
    ] = None
    payment_trans_status: typing_extensions.Annotated[
        typing.Optional[TransStatus],
        FieldMetadata(alias="PaymentTransStatus"),
        pydantic.Field(alias="PaymentTransStatus"),
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="Paypoint DBA name."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="Paypoint entryname."),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="Paypoint legal name."),
    ] = None
    response_data: typing_extensions.Annotated[
        typing.Optional[QueryResponseData], FieldMetadata(alias="ResponseData"), pydantic.Field(alias="ResponseData")
    ] = None
    schedule_reference: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ScheduleReference"),
        pydantic.Field(
            alias="ScheduleReference", description="Reference to the subscription originating the transaction."
        ),
    ] = None
    settled_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="SettledAmount"),
        pydantic.Field(alias="SettledAmount", description="The transaction amount."),
    ] = None
    settlement_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="SettlementDate"),
        pydantic.Field(
            alias="SettlementDate",
            description="The date and time when the transaction was settled. This field is null when the transaction's `SettlementStatus` is -1, -5, or -6 (Exception, Held, or Released).",
        ),
    ] = None
    source: typing_extensions.Annotated[
        typing.Optional[Source], FieldMetadata(alias="Source"), pydantic.Field(alias="Source")
    ] = None
    status: typing_extensions.Annotated[
        typing.Optional[SettlementStatus], FieldMetadata(alias="Status"), pydantic.Field(alias="Status")
    ] = None
    transaction_events: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryTransactionEvents]],
        FieldMetadata(alias="TransactionEvents"),
        pydantic.Field(alias="TransactionEvents", description="Events associated with this transaction."),
    ] = None
    transaction_time: typing_extensions.Annotated[
        typing.Optional[TransactionTime],
        FieldMetadata(alias="TransactionTime"),
        pydantic.Field(alias="TransactionTime"),
    ] = None
    trans_method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="TransMethod"),
        pydantic.Field(alias="TransMethod", description="Payment method used: card or ach."),
    ] = None
    type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Type"),
        pydantic.Field(alias="Type", description="The transaction type: credit or debit."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .batch_number import BatchNumber
from .bill_pay_out_data import BillPayOutData
from .comments import Comments
from .created_at import CreatedAt
from .dbaname import Dbaname
from .entrypointfield import Entrypointfield
from .external_paypoint_id import ExternalPaypointId
from .fee_amount import FeeAmount
from .file_content import FileContent
from .gatewayfield import Gatewayfield
from .has_vcard_transactions import HasVcardTransactions
from .is_same_day_ach import IsSameDayAch
from .last_modified import LastModified
from .legalname import Legalname
from .netamountnullable import Netamountnullable
from .org_parent_id import OrgParentId
from .org_parent_name import OrgParentName
from .payment_id_string import PaymentIdString
from .payout_program import PayoutProgram
from .query_payout_transaction_records_item_payment_data import QueryPayoutTransactionRecordsItemPaymentData
from .query_transaction_events import QueryTransactionEvents
from .risk_action import RiskAction
from .risk_action_code import RiskActionCode
from .risk_flagged import RiskFlagged
from .risk_flagged_on import RiskFlaggedOn
from .risk_reason import RiskReason
from .risk_status import RiskStatus
from .schedule_id import ScheduleId
from .settlement_status_payout import SettlementStatusPayout
from .source import Source
from .vendor_query_record import VendorQueryRecord


class QueryPayoutTransactionRecordsItem(UniversalBaseModel):
    batch_number: typing_extensions.Annotated[
        typing.Optional[BatchNumber], FieldMetadata(alias="BatchNumber"), pydantic.Field(alias="BatchNumber")
    ] = None
    batch_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchId"),
        pydantic.Field(alias="BatchId", description="Identifier of the batch associated with payout transaction."),
    ] = None
    bills: typing_extensions.Annotated[
        typing.Optional[typing.List[BillPayOutData]],
        FieldMetadata(alias="Bills"),
        pydantic.Field(alias="Bills", description="Events associated with this transaction."),
    ] = None
    card_token: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="CardToken"), pydantic.Field(alias="CardToken")
    ] = None
    check_data: typing_extensions.Annotated[
        typing.Optional[FileContent],
        FieldMetadata(alias="CheckData"),
        pydantic.Field(alias="CheckData", description="Object referencing paper check image."),
    ] = None
    check_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CheckNumber"),
        pydantic.Field(alias="CheckNumber", description="Paper check number related to payout transaction."),
    ] = None
    comments: typing_extensions.Annotated[
        typing.Optional[Comments],
        FieldMetadata(alias="Comments"),
        pydantic.Field(alias="Comments", description="Any comment or description for payout transaction."),
    ] = None
    created_at: typing_extensions.Annotated[
        typing.Optional[CreatedAt],
        FieldMetadata(alias="CreatedAt"),
        pydantic.Field(alias="CreatedAt", description="Timestamp when the payment was created, in UTC."),
    ] = None
    entry_name: typing_extensions.Annotated[
        typing.Optional[Entrypointfield], FieldMetadata(alias="EntryName"), pydantic.Field(alias="EntryName")
    ] = None
    events: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryTransactionEvents]],
        FieldMetadata(alias="Events"),
        pydantic.Field(alias="Events", description="Events associated with this transaction."),
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    fee_amount: typing_extensions.Annotated[
        typing.Optional[FeeAmount], FieldMetadata(alias="FeeAmount"), pydantic.Field(alias="FeeAmount")
    ] = None
    gateway: typing_extensions.Annotated[
        typing.Optional[Gatewayfield], FieldMetadata(alias="Gateway"), pydantic.Field(alias="Gateway")
    ] = None
    has_vcard_transactions: typing_extensions.Annotated[
        typing.Optional[HasVcardTransactions],
        FieldMetadata(alias="HasVcardTransactions"),
        pydantic.Field(alias="HasVcardTransactions"),
    ] = None
    id_out: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="IdOut"),
        pydantic.Field(alias="IdOut", description="Identifier of payout transaction."),
    ] = None
    is_same_day_ach: typing_extensions.Annotated[
        typing.Optional[IsSameDayAch], FieldMetadata(alias="IsSameDayACH"), pydantic.Field(alias="IsSameDayACH")
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[LastModified],
        FieldMetadata(alias="LastUpdated"),
        pydantic.Field(alias="LastUpdated", description="Timestamp when payment record was updated."),
    ] = None
    net_amount: typing_extensions.Annotated[
        typing.Optional[Netamountnullable],
        FieldMetadata(alias="NetAmount"),
        pydantic.Field(alias="NetAmount", description="Net amount paid."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    parent_org_id: typing_extensions.Annotated[
        typing.Optional[OrgParentId], FieldMetadata(alias="ParentOrgId"), pydantic.Field(alias="ParentOrgId")
    ] = None
    payment_data: typing_extensions.Annotated[
        typing.Optional[QueryPayoutTransactionRecordsItemPaymentData],
        FieldMetadata(alias="PaymentData"),
        pydantic.Field(alias="PaymentData"),
    ] = None
    payment_id: typing_extensions.Annotated[
        typing.Optional[PaymentIdString], FieldMetadata(alias="PaymentId"), pydantic.Field(alias="PaymentId")
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentMethod"),
        pydantic.Field(alias="PaymentMethod", description="The payment method for the transaction."),
    ] = None
    payment_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentStatus"),
        pydantic.Field(
            alias="PaymentStatus",
            description="Status of payout transaction. See [Payout Transaction Statuses](guides/money-out-statuses#payout-transaction-statuses) for a full reference.",
        ),
    ] = None
    payout_program: typing_extensions.Annotated[
        typing.Optional[PayoutProgram], FieldMetadata(alias="PayoutProgram"), pydantic.Field(alias="PayoutProgram")
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname], FieldMetadata(alias="PaypointDbaname"), pydantic.Field(alias="PaypointDbaname")
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="Paypoint legal name."),
    ] = None
    risk_action: typing_extensions.Annotated[
        typing.Optional[RiskAction], FieldMetadata(alias="RiskAction"), pydantic.Field(alias="RiskAction")
    ] = None
    risk_action_code: typing_extensions.Annotated[
        typing.Optional[RiskActionCode], FieldMetadata(alias="RiskActionCode"), pydantic.Field(alias="RiskActionCode")
    ] = None
    risk_flagged: typing_extensions.Annotated[
        typing.Optional[RiskFlagged], FieldMetadata(alias="RiskFlagged"), pydantic.Field(alias="RiskFlagged")
    ] = None
    risk_flagged_on: typing_extensions.Annotated[
        typing.Optional[RiskFlaggedOn], FieldMetadata(alias="RiskFlaggedOn"), pydantic.Field(alias="RiskFlaggedOn")
    ] = None
    risk_reason: typing_extensions.Annotated[
        typing.Optional[RiskReason], FieldMetadata(alias="RiskReason"), pydantic.Field(alias="RiskReason")
    ] = None
    risk_status: typing_extensions.Annotated[
        typing.Optional[RiskStatus], FieldMetadata(alias="RiskStatus"), pydantic.Field(alias="RiskStatus")
    ] = None
    schedule_id: typing_extensions.Annotated[
        typing.Optional[ScheduleId], FieldMetadata(alias="ScheduleId"), pydantic.Field(alias="ScheduleId")
    ] = None
    settlement_status: typing_extensions.Annotated[
        typing.Optional[SettlementStatusPayout],
        FieldMetadata(alias="SettlementStatus"),
        pydantic.Field(alias="SettlementStatus"),
    ] = None
    source: typing_extensions.Annotated[
        typing.Optional[Source], FieldMetadata(alias="Source"), pydantic.Field(alias="Source")
    ] = None
    status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="Status"),
        pydantic.Field(alias="Status", description="Internal status of transaction."),
    ] = None
    total_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="TotalAmount"),
        pydantic.Field(
            alias="TotalAmount", description="Transaction total amount (including service fee or sub-charge)."
        ),
    ] = None
    vendor: typing_extensions.Annotated[
        typing.Optional[VendorQueryRecord],
        FieldMetadata(alias="Vendor"),
        pydantic.Field(alias="Vendor", description="Vendor related to the payout transaction."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .v_2_response_action import V2ResponseAction
from .v_2_response_code import V2ResponseCode
from .v_2_response_explanation import V2ResponseExplanation
from .v_2_response_reason import V2ResponseReason
from .v_2_transaction_details import V2TransactionDetails


class V2DeclinedTransactionResponseWrapper(UniversalBaseModel):
    """
    Response wrapper for declined v2 Money In transaction endpoints (HTTP 402). Returned when a transaction is declined by the card network or issuer. All decline responses use this format with unified response codes starting with 'D'. The `data` field contains transaction details.

    Examples
    --------
    import datetime

    from payabli import BinData
    from payabli.money_in import (
        TransactionDetailCustomer,
        TransactionDetailEvent,
        TransactionDetailInvoiceData,
        TransactionDetailPaymentData,
        TransactionDetailPaymentDetails,
    )
    from payabli.v_2_money_in_types import (
        V2DeclinedTransactionResponseWrapper,
        V2TransactionDetailResponseData,
        V2TransactionDetails,
    )

    V2DeclinedTransactionResponseWrapper(
        code="D0100",
        reason="Declined",
        explanation="Generic decline from card network or card issuer",
        action="Use different card or payment method",
        data=V2TransactionDetails(
            parent_org_name="Mrinal's Pet Supplies",
            paypoint_dbaname="Mrinal's Pet Shop North",
            paypoint_legalname="Mrinal's Pet Shop North",
            paypoint_entryname="495147f647",
            payment_trans_id="3040-96dfa9a7c4ed4f82a3dd4a4a12ad28ae",
            connector_name="gp",
            external_processor_information="",
            gateway_trans_id="TRN_Ih68D6UZdip7OEQ2QFXat1yQSLF2nB",
            method="card",
            batch_number="3040_combined_20251201",
            batch_amount=420.0,
            payor_id=40144,
            payment_data=TransactionDetailPaymentData(
                masked_account="4XXXXXXXXXXX5439",
                account_type="visa",
                account_exp="12/25",
                holder_name="John Cassian",
                order_description="",
                bin_data=BinData(
                    bin_matched_length="6",
                    bin_card_brand="VISA",
                    bin_card_type="CREDIT",
                    bin_card_category="CLASSIC",
                    bin_card_issuer="",
                    bin_card_issuer_country="RUSSIAN FEDERATION",
                    bin_card_issuer_country_code_a_2="RU",
                    bin_card_issuer_country_number="643",
                    bin_card_is_regulated="",
                    bin_card_use_category="",
                    bin_card_issuer_country_code_a_3="",
                ),
                payment_details=TransactionDetailPaymentDetails(
                    total_amount=105.0,
                    service_fee=5.0,
                    check_unique_id="",
                    currency="USD",
                    categories=[],
                    split_funding=[],
                ),
            ),
            trans_status=3,
            paypoint_id=3040,
            total_amount=105.0,
            net_amount=100.0,
            fee_amount=5.0,
            settlement_status=0,
            operation="Sale",
            response_data=V2TransactionDetailResponseData(
                result_code="D0100",
                result_code_text="Declined",
                responsetext="DECLINE",
                transactionid="TRN_Ih68D6UZdip7OEQ2QFXat1yQSLF2nB",
                response_code="200",
                response_code_text="Do not honor",
            ),
            source="api",
            schedule_reference=0,
            org_id=17448,
            refund_id=0,
            returned_id=0,
            chargeback_id=0,
            retrieval_id=0,
            invoice_data=TransactionDetailInvoiceData(),
            entrypage_id=0,
            external_paypoint_id="",
            is_validated_ach=False,
            transaction_time="2025-12-01T09:50:03.559",
            customer=TransactionDetailCustomer(
                first_name="David",
                last_name="Beckham",
                company_name="Driving School LLC",
                billing_address_1="Home Address",
                billing_address_2="",
                billing_city="",
                billing_state="",
                billing_zip="45157",
                billing_country="US",
                billing_phone="+15555555555",
                billing_email="david.beckham@example.com",
                customer_number="C-90010",
                shipping_address_1="Home Address",
                shipping_address_2="",
                shipping_city="",
                shipping_state="",
                shipping_zip="45157",
                shipping_country="US",
                customer_id=40144,
                customer_status=0,
            ),
            cfee_transactions=[],
            transaction_events=[
                TransactionDetailEvent(
                    trans_event="Created",
                    event_data="0HNHD68HATSUC:00000001",
                    event_time="2025-12-01T09:50:02.558651",
                ),
                TransactionDetailEvent(
                    trans_event="Declined",
                    event_data="0HNHD68HATSUC:00000001",
                    event_time="2025-12-01T09:50:03.609111",
                ),
            ],
            pending_fee_amount=0.0,
            risk_flagged=False,
            risk_flagged_on=datetime.datetime.fromisoformat(
                "2025-12-01 09:50:02.547000+00:00",
            ),
            risk_status="PASSED",
            risk_reason="",
            risk_action="",
            risk_action_code=0,
            device_id="",
            ach_sec_code="",
            ach_holder_type="personal",
            ip_address="255.255.255.255",
            is_same_day_ach=False,
        ),
    )
    """

    code: V2ResponseCode
    reason: V2ResponseReason
    explanation: V2ResponseExplanation
    action: V2ResponseAction
    data: V2TransactionDetails
    token: typing.Optional[str] = pydantic.Field(default=None)
    """
    Pagination token (equivalent to `pageIdentifier` in v1 APIs). Returns `null` when pagination is not applicable.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .additional_data import AdditionalData
from .address_addtl_nullable import AddressAddtlNullable
from .address_nullable import AddressNullable
from .billing_data import BillingData
from .contacts_field import ContactsField
from .email import Email
from .location_code import LocationCode
from .mcc import Mcc
from .payee_name import PayeeName
from .remitaddress_1 import Remitaddress1
from .remitaddress_2 import Remitaddress2
from .remitcity import Remitcity
from .remitcountry import Remitcountry
from .remitstate import Remitstate
from .remitzip import Remitzip
from .vendor_number import VendorNumber
from .vendor_payment_method import VendorPaymentMethod
from .vendorid import Vendorid
from .vendorstatus import Vendorstatus


class VendorOutData(UniversalBaseModel):
    additional_data: typing_extensions.Annotated[
        typing.Optional[AdditionalData], FieldMetadata(alias="additionalData"), pydantic.Field(alias="additionalData")
    ] = None
    address_1: typing_extensions.Annotated[
        typing.Optional[AddressNullable],
        FieldMetadata(alias="Address1"),
        pydantic.Field(alias="Address1", description="Vendor's address"),
    ] = None
    address_2: typing_extensions.Annotated[
        typing.Optional[AddressAddtlNullable],
        FieldMetadata(alias="Address2"),
        pydantic.Field(alias="Address2", description="Additional line for vendor's address."),
    ] = None
    billing_data: typing_extensions.Annotated[
        typing.Optional[BillingData],
        FieldMetadata(alias="BillingData"),
        pydantic.Field(alias="BillingData", description="Object containing vendor's bank information."),
    ] = None
    city: typing_extensions.Annotated[
        str, FieldMetadata(alias="City"), pydantic.Field(alias="City", description="Vendor's city.")
    ]
    contacts: typing_extensions.Annotated[
        typing.Optional[ContactsField],
        FieldMetadata(alias="Contacts"),
        pydantic.Field(alias="Contacts", description="Array of objects describing the vendor's contacts."),
    ] = None
    country: typing_extensions.Annotated[
        str, FieldMetadata(alias="Country"), pydantic.Field(alias="Country", description="Vendor's country.")
    ]
    customer_vendor_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customerVendorAccount"),
        pydantic.Field(alias="customerVendorAccount", description="Account number of paypoint in the vendor side."),
    ] = None
    ein: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="EIN"),
        pydantic.Field(
            alias="EIN",
            description="EIN/Tax ID for vendor. In reponses, this field is masked, and looks like: `XXXXX6789`.",
        ),
    ]
    email: typing_extensions.Annotated[
        typing.Optional[Email],
        FieldMetadata(alias="Email"),
        pydantic.Field(alias="Email", description="Vendor's email address. Required for vCard."),
    ] = None
    internal_reference_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="InternalReferenceId"),
        pydantic.Field(alias="InternalReferenceId", description="Internal identifier for global vendor account."),
    ] = None
    location_code: typing_extensions.Annotated[
        typing.Optional[LocationCode], FieldMetadata(alias="LocationCode"), pydantic.Field(alias="LocationCode")
    ] = None
    mcc: typing_extensions.Annotated[typing.Optional[Mcc], FieldMetadata(alias="Mcc"), pydantic.Field(alias="Mcc")] = (
        None
    )
    name_1: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="Name1"),
        pydantic.Field(alias="Name1", description="Primary name for vendor. Required for new vendor."),
    ]
    name_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Name2"),
        pydantic.Field(alias="Name2", description="Secondary name for vendor."),
    ] = None
    payee_name_1: typing_extensions.Annotated[
        typing.Optional[PayeeName], FieldMetadata(alias="payeeName1"), pydantic.Field(alias="payeeName1")
    ] = None
    payee_name_2: typing_extensions.Annotated[
        typing.Optional[PayeeName], FieldMetadata(alias="payeeName2"), pydantic.Field(alias="payeeName2")
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[VendorPaymentMethod],
        FieldMetadata(alias="PaymentMethod"),
        pydantic.Field(alias="PaymentMethod"),
    ] = None
    phone: typing_extensions.Annotated[
        str, FieldMetadata(alias="Phone"), pydantic.Field(alias="Phone", description="Vendor's phone number")
    ]
    remit_address_1: typing_extensions.Annotated[
        typing.Optional[Remitaddress1], FieldMetadata(alias="remitAddress1"), pydantic.Field(alias="remitAddress1")
    ] = None
    remit_address_2: typing_extensions.Annotated[
        typing.Optional[Remitaddress2], FieldMetadata(alias="remitAddress2"), pydantic.Field(alias="remitAddress2")
    ] = None
    remit_city: typing_extensions.Annotated[
        typing.Optional[Remitcity], FieldMetadata(alias="remitCity"), pydantic.Field(alias="remitCity")
    ] = None
    remit_country: typing_extensions.Annotated[
        typing.Optional[Remitcountry], FieldMetadata(alias="remitCountry"), pydantic.Field(alias="remitCountry")
    ] = None
    remit_state: typing_extensions.Annotated[
        typing.Optional[Remitstate], FieldMetadata(alias="remitState"), pydantic.Field(alias="remitState")
    ] = None
    remit_zip: typing_extensions.Annotated[
        typing.Optional[Remitzip], FieldMetadata(alias="remitZip"), pydantic.Field(alias="remitZip")
    ] = None
    state: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="State"),
        pydantic.Field(alias="State", description="Vendor's state. Must be a 2 character state code."),
    ]
    vendor_id: typing_extensions.Annotated[
        typing.Optional[Vendorid],
        FieldMetadata(alias="VendorId"),
        pydantic.Field(
            alias="VendorId",
            description="Payabli identifier for vendor record. Required when `VendorNumber` isn't included.",
        ),
    ] = None
    vendor_number: typing_extensions.Annotated[
        typing.Optional[VendorNumber], FieldMetadata(alias="VendorNumber"), pydantic.Field(alias="VendorNumber")
    ] = None
    vendor_status: typing_extensions.Annotated[
        typing.Optional[Vendorstatus], FieldMetadata(alias="VendorStatus"), pydantic.Field(alias="VendorStatus")
    ] = None
    zip: typing_extensions.Annotated[
        str, FieldMetadata(alias="Zip"), pydantic.Field(alias="Zip", description="Vendor's zip code.")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .max_ticket import MaxTicket
from .min_ticket import MinTicket


class PayabliCredentialsPascal(UniversalBaseModel):
    service: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="Service"), pydantic.Field(alias="Service")
    ] = None
    mode: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="Mode"), pydantic.Field(alias="Mode")
    ] = None
    min_ticket: typing_extensions.Annotated[
        typing.Optional[MinTicket], FieldMetadata(alias="MinTicket"), pydantic.Field(alias="MinTicket")
    ] = None
    max_ticket: typing_extensions.Annotated[
        typing.Optional[MaxTicket], FieldMetadata(alias="MaxTicket"), pydantic.Field(alias="MaxTicket")
    ] = None
    cfee_fix: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="CfeeFix"), pydantic.Field(alias="CfeeFix")
    ] = None
    cfee_float: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="CfeeFloat"), pydantic.Field(alias="CfeeFloat")
    ] = None
    cfee_min: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="CfeeMin"), pydantic.Field(alias="CfeeMin")
    ] = None
    cfee_max: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="CfeeMax"), pydantic.Field(alias="CfeeMax")
    ] = None
    account_id: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="AccountId"), pydantic.Field(alias="AccountId")
    ] = None
    reference_id: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="ReferenceId"), pydantic.Field(alias="ReferenceId")
    ] = None
    accept_same_day_ach: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="acceptSameDayACH"), pydantic.Field(alias="acceptSameDayACH")
    ] = None
    currency: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Currency"),
        pydantic.Field(alias="Currency", description="The default currency for the paypoint, either `USD` or `CAD`."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class CardSetup(UniversalBaseModel):
    accept_amex: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="acceptAmex"),
        pydantic.Field(alias="acceptAmex", description="Determines whether American Express is accepted."),
    ] = None
    accept_discover: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="acceptDiscover"),
        pydantic.Field(alias="acceptDiscover", description="Determines whether Discover is accepted."),
    ] = None
    accept_mastercard: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="acceptMastercard"),
        pydantic.Field(alias="acceptMastercard", description="Determines whether Mastercard is accepted."),
    ] = None
    accept_visa: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="acceptVisa"),
        pydantic.Field(alias="acceptVisa", description="Determines whether Visa is accepted."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.batch_number import BatchNumber
from ...types.dbaname import Dbaname
from ...types.deposit_date import DepositDate
from ...types.entrypointfield import Entrypointfield
from ...types.expected_deposit_date import ExpectedDepositDate
from ...types.external_paypoint_id import ExternalPaypointId
from ...types.general_events import GeneralEvents
from ...types.org_parent_name import OrgParentName
from ...types.paypoint_id import PaypointId
from ...types.paypoint_name import PaypointName
from ...types.transfer_identifier import TransferIdentifier
from .query_batches_transfer import QueryBatchesTransfer


class QueryBatchesResponseRecordsItem(UniversalBaseModel):
    id_batch: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="IdBatch"),
        pydantic.Field(alias="IdBatch", description="The batch ID."),
    ] = None
    batch_number: typing_extensions.Annotated[
        typing.Optional[BatchNumber], FieldMetadata(alias="BatchNumber"), pydantic.Field(alias="BatchNumber")
    ] = None
    transfer_identifier: typing_extensions.Annotated[
        typing.Optional[TransferIdentifier],
        FieldMetadata(alias="TransferIdentifier"),
        pydantic.Field(alias="TransferIdentifier"),
    ] = None
    events_data: typing_extensions.Annotated[
        typing.Optional[typing.List[GeneralEvents]],
        FieldMetadata(alias="EventsData"),
        pydantic.Field(alias="EventsData", description="Events associated with the batch."),
    ] = None
    connector_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ConnectorName"),
        pydantic.Field(alias="ConnectorName", description=""),
    ] = None
    batch_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="BatchDate"),
        pydantic.Field(alias="BatchDate", description="The batch date."),
    ] = None
    batch_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchAmount"),
        pydantic.Field(alias="BatchAmount", description="The amount of the batch."),
    ] = None
    batch_fees_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchFeesAmount"),
        pydantic.Field(alias="BatchFeesAmount", description="The total of fees in the batch."),
    ] = None
    batch_auth_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchAuthAmount"),
        pydantic.Field(alias="BatchAuthAmount", description=""),
    ] = None
    batch_released_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchReleasedAmount"),
        pydantic.Field(
            alias="BatchReleasedAmount",
            description="Previously held funds that have been released after a risk review.",
        ),
    ] = None
    batch_hold_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchHoldAmount"),
        pydantic.Field(
            alias="BatchHoldAmount",
            description="The total amount of the batch that's being held for fraud or risk concerns.",
        ),
    ] = None
    batch_returned_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchReturnedAmount"),
        pydantic.Field(alias="BatchReturnedAmount", description="Total amount of ACH returns deducted from batch."),
    ] = None
    batch_refund_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchRefundAmount"),
        pydantic.Field(alias="BatchRefundAmount", description="The total amount of refunds deducted from batch."),
    ] = None
    batch_split_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchSplitAmount"),
        pydantic.Field(
            alias="BatchSplitAmount",
            description="Total of split transactions that included split funding instructions at the time of authorization.",
        ),
    ] = None
    batch_status: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="BatchStatus"),
        pydantic.Field(
            alias="BatchStatus",
            description="The batch status. See [Batch Status](/developers/references/money-in-statuses#batch-status) for more.",
        ),
    ]
    batch_records: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="BatchRecords"),
        pydantic.Field(alias="BatchRecords", description="The number of records in the batch."),
    ]
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[PaypointId], FieldMetadata(alias="PaypointId"), pydantic.Field(alias="PaypointId")
    ] = None
    paypoint_name: typing_extensions.Annotated[
        typing.Optional[PaypointName], FieldMetadata(alias="PaypointName"), pydantic.Field(alias="PaypointName")
    ] = None
    paypoint_dba: typing_extensions.Annotated[
        typing.Optional[Dbaname], FieldMetadata(alias="PaypointDba"), pydantic.Field(alias="PaypointDba")
    ] = None
    parent_org_name: typing_extensions.Annotated[
        OrgParentName,
        FieldMetadata(alias="ParentOrgName"),
        pydantic.Field(alias="ParentOrgName", description="The entrypoint's parent org."),
    ]
    parent_org_id: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="ParentOrgId"),
        pydantic.Field(alias="ParentOrgId", description="The parent organization ID."),
    ]
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    entry_name: typing_extensions.Annotated[
        Entrypointfield, FieldMetadata(alias="EntryName"), pydantic.Field(alias="EntryName")
    ]
    bank_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="BankName"),
        pydantic.Field(alias="BankName", description="The bank name."),
    ] = None
    batch_type: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchType"),
        pydantic.Field(alias="BatchType", description="The batch type."),
    ] = None
    method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Method"),
        pydantic.Field(alias="Method", description="The payment method used."),
    ] = None
    expected_deposit_date: typing_extensions.Annotated[
        typing.Optional[ExpectedDepositDate],
        FieldMetadata(alias="ExpectedDepositDate"),
        pydantic.Field(alias="ExpectedDepositDate"),
    ] = None
    deposit_date: typing_extensions.Annotated[
        typing.Optional[DepositDate], FieldMetadata(alias="DepositDate"), pydantic.Field(alias="DepositDate")
    ] = None
    transfer_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="TransferDate"),
        pydantic.Field(alias="TransferDate", description="The batch transfer date."),
    ] = None
    transfer: typing_extensions.Annotated[
        typing.Optional[QueryBatchesTransfer],
        FieldMetadata(alias="Transfer"),
        pydantic.Field(alias="Transfer", description="Transfer details for the batch."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.is_success import IsSuccess
from ...types.response_text import ResponseText


class RemoveSubscriptionResponse(UniversalBaseModel):
    """
    Success response
    """

    is_success: typing_extensions.Annotated[
        typing.Optional[IsSuccess], FieldMetadata(alias="isSuccess"), pydantic.Field(alias="isSuccess")
    ] = None
    response_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="responseData"),
        pydantic.Field(
            alias="responseData",
            description="\nIf `isSuccess` = true, this contains the identifier of the subscription.\n\nIf `isSuccess` = false, this contains the reason for the failure.",
        ),
    ] = None
    response_text: typing_extensions.Annotated[
        ResponseText, FieldMetadata(alias="responseText"), pydantic.Field(alias="responseText")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .transfer_message_properties import TransferMessageProperties


class TransferMessage(UniversalBaseModel):
    id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="Id"), pydantic.Field(alias="Id")] = None
    room_id: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="RoomId"), pydantic.Field(alias="RoomId")
    ] = None
    user_id: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="UserId"), pydantic.Field(alias="UserId")
    ] = None
    user_name: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="UserName"), pydantic.Field(alias="UserName")
    ] = None
    content: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="Content"), pydantic.Field(alias="Content")
    ] = None
    created_at: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="CreatedAt"), pydantic.Field(alias="CreatedAt")
    ] = None
    message_type: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="MessageType"), pydantic.Field(alias="MessageType")
    ] = None
    message_properties: typing_extensions.Annotated[
        typing.Optional[TransferMessageProperties],
        FieldMetadata(alias="MessageProperties"),
        pydantic.Field(alias="MessageProperties"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.additional_data import AdditionalData
from ...types.address_addtl_nullable import AddressAddtlNullable
from ...types.address_nullable import AddressNullable
from ...types.billing_data import BillingData
from ...types.contacts_field import ContactsField
from ...types.email import Email
from ...types.location_code import LocationCode
from ...types.mcc import Mcc
from ...types.payee_name import PayeeName
from ...types.remitaddress_1 import Remitaddress1
from ...types.remitaddress_2 import Remitaddress2
from ...types.remitcity import Remitcity
from ...types.remitcountry import Remitcountry
from ...types.remitstate import Remitstate
from ...types.remitzip import Remitzip
from ...types.vendor_ein import VendorEin
from ...types.vendor_name_1 import VendorName1
from ...types.vendor_name_2 import VendorName2
from ...types.vendor_number import VendorNumber
from ...types.vendor_payment_method import VendorPaymentMethod
from ...types.vendor_phone import VendorPhone
from ...types.vendorid import Vendorid
from ...types.vendorstatus import Vendorstatus


class RequestOutAuthorizeVendorDataOld(UniversalBaseModel):
    """
    Object containing vendor data.
    """

    additional_data: typing_extensions.Annotated[
        typing.Optional[AdditionalData], FieldMetadata(alias="additionalData"), pydantic.Field(alias="additionalData")
    ] = None
    address_1: typing_extensions.Annotated[
        typing.Optional[AddressNullable],
        FieldMetadata(alias="address1"),
        pydantic.Field(alias="address1", description="Vendor's address"),
    ] = None
    address_2: typing_extensions.Annotated[
        typing.Optional[AddressAddtlNullable],
        FieldMetadata(alias="address2"),
        pydantic.Field(alias="address2", description="Additional line for vendor's address."),
    ] = None
    billing_data: typing_extensions.Annotated[
        typing.Optional[BillingData],
        FieldMetadata(alias="billingData"),
        pydantic.Field(alias="billingData", description="Object containing vendor's bank information."),
    ] = None
    city: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's city.
    """

    contacts: typing.Optional[ContactsField] = pydantic.Field(default=None)
    """
    Array of objects describing the vendor's contacts.
    """

    country: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's country.
    """

    customer_vendor_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customerVendorAccount"),
        pydantic.Field(alias="customerVendorAccount", description="Account number of paypoint in the vendor side."),
    ] = None
    custom_field_1: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="customField1"), pydantic.Field(alias="customField1")
    ] = None
    custom_field_2: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="customField2"), pydantic.Field(alias="customField2")
    ] = None
    ein: typing.Optional[VendorEin] = None
    email: typing.Optional[Email] = pydantic.Field(default=None)
    """
    Vendor's email address. Required for vCard.
    """

    internal_reference_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="internalReferenceId"),
        pydantic.Field(alias="internalReferenceId", description="Internal identifier for global vendor account."),
    ] = None
    location_code: typing_extensions.Annotated[
        typing.Optional[LocationCode], FieldMetadata(alias="locationCode"), pydantic.Field(alias="locationCode")
    ] = None
    mcc: typing.Optional[Mcc] = None
    name_1: typing_extensions.Annotated[
        typing.Optional[VendorName1], FieldMetadata(alias="name1"), pydantic.Field(alias="name1")
    ] = None
    name_2: typing_extensions.Annotated[
        typing.Optional[VendorName2], FieldMetadata(alias="name2"), pydantic.Field(alias="name2")
    ] = None
    payee_name_1: typing_extensions.Annotated[
        typing.Optional[PayeeName], FieldMetadata(alias="payeeName1"), pydantic.Field(alias="payeeName1")
    ] = None
    payee_name_2: typing_extensions.Annotated[
        typing.Optional[PayeeName], FieldMetadata(alias="payeeName2"), pydantic.Field(alias="payeeName2")
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[VendorPaymentMethod],
        FieldMetadata(alias="paymentMethod"),
        pydantic.Field(alias="paymentMethod"),
    ] = None
    phone: typing.Optional[VendorPhone] = None
    remit_address_1: typing_extensions.Annotated[
        typing.Optional[Remitaddress1], FieldMetadata(alias="remitAddress1"), pydantic.Field(alias="remitAddress1")
    ] = None
    remit_address_2: typing_extensions.Annotated[
        typing.Optional[Remitaddress2], FieldMetadata(alias="remitAddress2"), pydantic.Field(alias="remitAddress2")
    ] = None
    remit_city: typing_extensions.Annotated[
        typing.Optional[Remitcity], FieldMetadata(alias="remitCity"), pydantic.Field(alias="remitCity")
    ] = None
    remit_country: typing_extensions.Annotated[
        typing.Optional[Remitcountry], FieldMetadata(alias="remitCountry"), pydantic.Field(alias="remitCountry")
    ] = None
    remit_state: typing_extensions.Annotated[
        typing.Optional[Remitstate], FieldMetadata(alias="remitState"), pydantic.Field(alias="remitState")
    ] = None
    remit_zip: typing_extensions.Annotated[
        typing.Optional[Remitzip], FieldMetadata(alias="remitZip"), pydantic.Field(alias="remitZip")
    ] = None
    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's state. Must be a 2 character state code.
    """

    vendor_id: typing_extensions.Annotated[
        typing.Optional[Vendorid],
        FieldMetadata(alias="vendorId"),
        pydantic.Field(
            alias="vendorId",
            description="Payabli identifier for vendor record. Required when `vendorNumber` isn't included.",
        ),
    ] = None
    vendor_number: typing_extensions.Annotated[
        typing.Optional[VendorNumber], FieldMetadata(alias="vendorNumber"), pydantic.Field(alias="vendorNumber")
    ] = None
    vendor_status: typing_extensions.Annotated[
        typing.Optional[Vendorstatus], FieldMetadata(alias="vendorStatus"), pydantic.Field(alias="vendorStatus")
    ] = None
    zip: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's postal code.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .v_2_bad_request_error import V2BadRequestError
    from .v_2_bad_request_error_detail import V2BadRequestErrorDetail
    from .v_2_declined_transaction_response_wrapper import V2DeclinedTransactionResponseWrapper
    from .v_2_internal_server_error import V2InternalServerError
    from .v_2_response_action import V2ResponseAction
    from .v_2_response_code import V2ResponseCode
    from .v_2_response_explanation import V2ResponseExplanation
    from .v_2_response_reason import V2ResponseReason
    from .v_2_transaction_detail_response_data import V2TransactionDetailResponseData
    from .v_2_transaction_details import V2TransactionDetails
    from .v_2_transaction_response_wrapper import V2TransactionResponseWrapper
_dynamic_imports: typing.Dict[str, str] = {
    "V2BadRequestError": ".v_2_bad_request_error",
    "V2BadRequestErrorDetail": ".v_2_bad_request_error_detail",
    "V2DeclinedTransactionResponseWrapper": ".v_2_declined_transaction_response_wrapper",
    "V2InternalServerError": ".v_2_internal_server_error",
    "V2ResponseAction": ".v_2_response_action",
    "V2ResponseCode": ".v_2_response_code",
    "V2ResponseExplanation": ".v_2_response_explanation",
    "V2ResponseReason": ".v_2_response_reason",
    "V2TransactionDetailResponseData": ".v_2_transaction_detail_response_data",
    "V2TransactionDetails": ".v_2_transaction_details",
    "V2TransactionResponseWrapper": ".v_2_transaction_response_wrapper",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "V2BadRequestError",
    "V2BadRequestErrorDetail",
    "V2DeclinedTransactionResponseWrapper",
    "V2InternalServerError",
    "V2ResponseAction",
    "V2ResponseCode",
    "V2ResponseExplanation",
    "V2ResponseReason",
    "V2TransactionDetailResponseData",
    "V2TransactionDetails",
    "V2TransactionResponseWrapper",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .batch_number import BatchNumber
from .entrypointfield import Entrypointfield
from .external_paypoint_id import ExternalPaypointId


class QueryBatchesOutResponseRecordsItem(UniversalBaseModel):
    ach_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="AchAmount"), pydantic.Field(alias="AchAmount", description="")
    ] = None
    ach_records: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="AchRecords"), pydantic.Field(alias="AchRecords", description="")
    ] = None
    ach_status: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="AchStatus"), pydantic.Field(alias="AchStatus", description="")
    ] = None
    ach_status_text: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="AchStatusText"),
        pydantic.Field(alias="AchStatusText", description=""),
    ] = None
    batch_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchAmount"),
        pydantic.Field(alias="BatchAmount", description="The amount of the batch."),
    ] = None
    batch_cancelled_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchCancelledAmount"),
        pydantic.Field(alias="BatchCancelledAmount", description=""),
    ] = None
    batch_cancelled_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchCancelledRecords"),
        pydantic.Field(alias="BatchCancelledRecords", description=""),
    ] = None
    batch_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="BatchDate"),
        pydantic.Field(alias="BatchDate", description="The batch date."),
    ] = None
    batch_number: typing_extensions.Annotated[
        typing.Optional[BatchNumber], FieldMetadata(alias="BatchNumber"), pydantic.Field(alias="BatchNumber")
    ] = None
    batch_paid_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchPaidAmount"),
        pydantic.Field(alias="BatchPaidAmount", description=""),
    ] = None
    batch_paid_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchPaidRecords"),
        pydantic.Field(alias="BatchPaidRecords", description=""),
    ] = None
    batch_processed_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchProcessedAmount"),
        pydantic.Field(alias="BatchProcessedAmount", description=""),
    ] = None
    batch_processed_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchProcessedRecords"),
        pydantic.Field(alias="BatchProcessedRecords", description=""),
    ] = None
    batch_processing_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchProcessingAmount"),
        pydantic.Field(alias="BatchProcessingAmount", description=""),
    ] = None
    batch_processing_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchProcessingRecords"),
        pydantic.Field(alias="BatchProcessingRecords", description=""),
    ] = None
    batch_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchRecords"),
        pydantic.Field(alias="BatchRecords", description="The number of records in the batch."),
    ] = None
    batch_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="BatchStatus"),
        pydantic.Field(
            alias="BatchStatus",
            description="The batch status. See [Batch Status](/developers/references/money-out-statuses#batch-statuses) for more.",
        ),
    ] = None
    batch_status_text: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="BatchStatusText"),
        pydantic.Field(alias="BatchStatusText", description="A text description of the batch status."),
    ] = None
    card_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="CardAmount"), pydantic.Field(alias="CardAmount", description="")
    ] = None
    card_records: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="CardRecords"), pydantic.Field(alias="CardRecords", description="")
    ] = None
    card_status: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="CardStatus"), pydantic.Field(alias="CardStatus", description="")
    ] = None
    card_status_text: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CardStatusText"),
        pydantic.Field(alias="CardStatusText", description=""),
    ] = None
    check_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="CheckAmount"), pydantic.Field(alias="CheckAmount", description="")
    ] = None
    check_records: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="CheckRecords"), pydantic.Field(alias="CheckRecords", description="")
    ] = None
    check_status: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="CheckStatus"), pydantic.Field(alias="CheckStatus", description="")
    ] = None
    check_status_text: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CheckStatusText"),
        pydantic.Field(alias="CheckStatusText", description=""),
    ] = None
    entry_name: typing_extensions.Annotated[
        typing.Optional[Entrypointfield], FieldMetadata(alias="EntryName"), pydantic.Field(alias="EntryName")
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    id_batch: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="IdBatch"),
        pydantic.Field(alias="IdBatch", description="The batch ID."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ParentOrgName"),
        pydantic.Field(alias="ParentOrgName", description="The entrypoint's parent org."),
    ] = None
    paypoint_dba: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointDba"),
        pydantic.Field(alias="PaypointDba", description="Paypoint DBA name."),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="PaypointId"),
        pydantic.Field(alias="PaypointId", description="Paypoint ID."),
    ] = None
    paypoint_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointName"),
        pydantic.Field(alias="PaypointName", description="Paypoint legal name."),
    ] = None
    vcard_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="VcardAmount"), pydantic.Field(alias="VcardAmount", description="")
    ] = None
    vcard_records: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="VcardRecords"), pydantic.Field(alias="VcardRecords", description="")
    ] = None
    vcard_status: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="VcardStatus"), pydantic.Field(alias="VcardStatus", description="")
    ] = None
    vcard_status_text: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="VcardStatusText"),
        pydantic.Field(alias="VcardStatusText", description=""),
    ] = None
    wire_amount: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="WireAmount"), pydantic.Field(alias="WireAmount", description="")
    ] = None
    wire_records: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="WireRecords"), pydantic.Field(alias="WireRecords", description="")
    ] = None
    wire_status: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="WireStatus"), pydantic.Field(alias="WireStatus", description="")
    ] = None
    wire_status_text: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="WireStatusText"),
        pydantic.Field(alias="WireStatusText", description=""),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .transfer_out_bank_account import TransferOutBankAccount
from .transfer_out_event_data import TransferOutEventData
from .transfer_out_message import TransferOutMessage


class TransferOutRecord(UniversalBaseModel):
    """
    A record representing an outbound transfer.
    """

    transfer_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="transferId"),
        pydantic.Field(alias="transferId", description="Unique identifier for the transfer."),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="paypointId"),
        pydantic.Field(alias="paypointId", description="The ID of the paypoint associated with the transfer."),
    ] = None
    batch_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="batchNumber"),
        pydantic.Field(alias="batchNumber", description="The batch number for the transfer."),
    ] = None
    batch_currency: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="batchCurrency"),
        pydantic.Field(alias="batchCurrency", description="The currency of the batch."),
    ] = None
    batch_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="batchRecords"),
        pydantic.Field(alias="batchRecords", description="The number of records in the batch."),
    ] = None
    transfer_identifier: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="transferIdentifier"),
        pydantic.Field(alias="transferIdentifier", description="An identifier for the transfer."),
    ] = None
    batch_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="batchId"),
        pydantic.Field(alias="batchId", description="The ID of the batch."),
    ] = None
    batch_net_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="batchNetAmount"),
        pydantic.Field(alias="batchNetAmount", description="The net amount of the batch."),
    ] = None
    batch_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="batchStatus"),
        pydantic.Field(alias="batchStatus", description="The status of the batch."),
    ] = None
    paypoint_entry_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointEntryName"),
        pydantic.Field(alias="paypointEntryName", description="The entry name for the paypoint."),
    ] = None
    paypoint_legal_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointLegalName"),
        pydantic.Field(alias="paypointLegalName", description="The legal name of the paypoint."),
    ] = None
    paypoint_dba_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointDbaName"),
        pydantic.Field(alias="paypointDbaName", description="The DBA name of the paypoint."),
    ] = None
    paypoint_logo: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointLogo"),
        pydantic.Field(alias="paypointLogo", description="URL to the paypoint's logo."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="parentOrgName"),
        pydantic.Field(alias="parentOrgName", description="The name of the parent organization."),
    ] = None
    parent_org_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="parentOrgId"),
        pydantic.Field(alias="parentOrgId", description="The ID of the parent organization."),
    ] = None
    parent_org_logo: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="parentOrgLogo"),
        pydantic.Field(alias="parentOrgLogo", description="URL to the parent organization's logo."),
    ] = None
    parent_org_entry_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="parentOrgEntryName"),
        pydantic.Field(alias="parentOrgEntryName", description="The entry name for the parent organization."),
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID", description="External identifier for the paypoint."),
    ] = None
    bank_account: typing_extensions.Annotated[
        typing.Optional[TransferOutBankAccount],
        FieldMetadata(alias="bankAccount"),
        pydantic.Field(alias="bankAccount", description="Bank account information for the transfer."),
    ] = None
    transfer_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="transferDate"),
        pydantic.Field(alias="transferDate", description="The date of the transfer."),
    ] = None
    processor: typing.Optional[str] = pydantic.Field(default=None)
    """
    The processor used for the transfer.
    """

    transfer_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="transferStatus"),
        pydantic.Field(alias="transferStatus", description="The status of the transfer."),
    ] = None
    gross_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="grossAmount"),
        pydantic.Field(alias="grossAmount", description="The gross amount of the transfer."),
    ] = None
    charge_back_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="chargeBackAmount"),
        pydantic.Field(alias="chargeBackAmount", description="The chargeback amount deducted from the transfer."),
    ] = None
    returned_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="returnedAmount"),
        pydantic.Field(alias="returnedAmount", description="The returned amount deducted from the transfer."),
    ] = None
    hold_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="holdAmount"),
        pydantic.Field(alias="holdAmount", description="The amount being held."),
    ] = None
    released_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="releasedAmount"),
        pydantic.Field(alias="releasedAmount", description="The amount that has been released."),
    ] = None
    billing_fees_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="billingFeesAmount"),
        pydantic.Field(alias="billingFeesAmount", description="The billing fees amount."),
    ] = None
    third_party_paid_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="thirdPartyPaidAmount"),
        pydantic.Field(alias="thirdPartyPaidAmount", description="The third party paid amount."),
    ] = None
    adjustments_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="adjustmentsAmount"),
        pydantic.Field(alias="adjustmentsAmount", description="The adjustments amount."),
    ] = None
    net_transfer_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="netTransferAmount"),
        pydantic.Field(alias="netTransferAmount", description="The net transfer amount after all deductions."),
    ] = None
    split_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="splitAmount"),
        pydantic.Field(alias="splitAmount", description="The split funding amount."),
    ] = None
    events_data: typing_extensions.Annotated[
        typing.Optional[typing.List[TransferOutEventData]],
        FieldMetadata(alias="eventsData"),
        pydantic.Field(alias="eventsData", description="List of events associated with the transfer."),
    ] = None
    messages: typing.Optional[typing.List[TransferOutMessage]] = pydantic.Field(default=None)
    """
    List of messages associated with the transfer.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .template_element import TemplateElement
from .visible import Visible


class CardFeeSection(UniversalBaseModel):
    ach_batch_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="achBatchCardFee"),
        pydantic.Field(alias="achBatchCardFee"),
    ] = None
    annual_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement], FieldMetadata(alias="annualCardFee"), pydantic.Field(alias="annualCardFee")
    ] = None
    avs_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement], FieldMetadata(alias="avsCardFee"), pydantic.Field(alias="avsCardFee")
    ] = None
    chargeback_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="chargebackCardFee"),
        pydantic.Field(alias="chargebackCardFee"),
    ] = None
    dda_rejects_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="ddaRejectsCardFee"),
        pydantic.Field(alias="ddaRejectsCardFee"),
    ] = None
    early_termination_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="earlyTerminationCardFee"),
        pydantic.Field(alias="earlyTerminationCardFee"),
    ] = None
    minimum_processing_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="minimumProcessingCardFee"),
        pydantic.Field(alias="minimumProcessingCardFee"),
    ] = None
    monthly_pci_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="monthlyPCICardFee"),
        pydantic.Field(alias="monthlyPCICardFee"),
    ] = None
    montly_platform_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="montlyPlatformCardFee"),
        pydantic.Field(alias="montlyPlatformCardFee"),
    ] = None
    retrieval_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="retrievalCardFee"),
        pydantic.Field(alias="retrievalCardFee"),
    ] = None
    transaction_card_fee: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="transactionCardFee"),
        pydantic.Field(alias="transactionCardFee"),
    ] = None
    visible: typing.Optional[Visible] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .transfer_out_message_properties import TransferOutMessageProperties


class TransferOutMessage(UniversalBaseModel):
    """
    A message associated with an outbound transfer.
    """

    id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="Id"),
        pydantic.Field(alias="Id", description="Unique identifier for the message."),
    ] = None
    room_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="RoomId"),
        pydantic.Field(alias="RoomId", description="The ID of the room where the message was sent."),
    ] = None
    user_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="UserId"),
        pydantic.Field(alias="UserId", description="The ID of the user who sent the message."),
    ] = None
    user_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="UserName"),
        pydantic.Field(alias="UserName", description="The name of the user who sent the message."),
    ] = None
    content: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Content"),
        pydantic.Field(alias="Content", description="The content of the message."),
    ] = None
    created_at: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CreatedAt"),
        pydantic.Field(alias="CreatedAt", description="The time the message was created."),
    ] = None
    message_type: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="MessageType"),
        pydantic.Field(alias="MessageType", description="The type of message."),
    ] = None
    message_properties: typing_extensions.Annotated[
        typing.Optional[TransferOutMessageProperties],
        FieldMetadata(alias="MessageProperties"),
        pydantic.Field(alias="MessageProperties", description="Additional properties for the message."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.customeridtrans import Customeridtrans
from ...types.referenceidtrans import Referenceidtrans
from ...types.result_code import ResultCode
from ...types.resulttext import Resulttext


class CaptureAllOutResponseResponseDataItem(UniversalBaseModel):
    customer_id: typing_extensions.Annotated[
        typing.Optional[Customeridtrans],
        FieldMetadata(alias="CustomerId"),
        pydantic.Field(
            alias="CustomerId",
            description="Internal unique Id of vendor owner of transaction. Returns `0` if the transaction wasn't assigned to an existing vendor or no vendor was created.",
        ),
    ] = None
    reference_id: typing_extensions.Annotated[
        typing.Optional[Referenceidtrans], FieldMetadata(alias="ReferenceId"), pydantic.Field(alias="ReferenceId")
    ] = None
    result_code: typing_extensions.Annotated[
        typing.Optional[ResultCode], FieldMetadata(alias="ResultCode"), pydantic.Field(alias="ResultCode")
    ] = None
    result_text: typing_extensions.Annotated[
        typing.Optional[Resulttext],
        FieldMetadata(alias="ResultText"),
        pydantic.Field(
            alias="ResultText",
            description="Text describing the result. \nIf `ResultCode`` = 1, returns 'Authorized'. \nIf `ResultCode` = 2 or 3, this contains the cause of the decline.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .ach_holder_type import AchHolderType
from .ach_sec_code import AchSecCode
from .batch_number import BatchNumber
from .bill_data import BillData
from .datetime_nullable import DatetimeNullable
from .dbaname import Dbaname
from .device import Device
from .entrypage_id import EntrypageId
from .entrypointfield import Entrypointfield
from .external_processor_information import ExternalProcessorInformation
from .fee_amount import FeeAmount
from .legalname import Legalname
from .netamountnullable import Netamountnullable
from .operation import Operation
from .order_id import OrderId
from .org_parent_name import OrgParentName
from .orgid import Orgid
from .payor_id import PayorId
from .pending_fee_amount import PendingFeeAmount
from .query_c_fee_transaction import QueryCFeeTransaction
from .query_payment_data import QueryPaymentData
from .query_response_data import QueryResponseData
from .query_transaction_events import QueryTransactionEvents
from .query_transaction_payor_data_customer import QueryTransactionPayorDataCustomer
from .refund_id import RefundId
from .returned_id import ReturnedId
from .source import Source
from .split_funding import SplitFunding


class TransactionQueryRecordsCustomer(UniversalBaseModel):
    ach_holder_type: typing_extensions.Annotated[
        typing.Optional[AchHolderType], FieldMetadata(alias="AchHolderType"), pydantic.Field(alias="AchHolderType")
    ] = None
    ach_sec_code: typing_extensions.Annotated[
        typing.Optional[AchSecCode], FieldMetadata(alias="AchSecCode"), pydantic.Field(alias="AchSecCode")
    ] = None
    batch_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchAmount"),
        pydantic.Field(alias="BatchAmount", description="Batch amount."),
    ] = None
    batch_number: typing_extensions.Annotated[
        typing.Optional[BatchNumber], FieldMetadata(alias="BatchNumber"), pydantic.Field(alias="BatchNumber")
    ] = None
    cfee_transactions: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryCFeeTransaction]],
        FieldMetadata(alias="CfeeTransactions"),
        pydantic.Field(
            alias="CfeeTransactions",
            description="Service Fee or sub-charge transaction associated to the main transaction.",
        ),
    ] = None
    connector_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ConnectorName"),
        pydantic.Field(alias="ConnectorName", description="Connector used for transaction."),
    ] = None
    customer: typing_extensions.Annotated[
        typing.Optional[QueryTransactionPayorDataCustomer],
        FieldMetadata(alias="Customer"),
        pydantic.Field(alias="Customer"),
    ] = None
    device_id: typing_extensions.Annotated[
        typing.Optional[Device], FieldMetadata(alias="DeviceId"), pydantic.Field(alias="DeviceId")
    ] = None
    entrypage_id: typing_extensions.Annotated[
        typing.Optional[EntrypageId], FieldMetadata(alias="EntrypageId"), pydantic.Field(alias="EntrypageId")
    ] = None
    external_processor_information: typing_extensions.Annotated[
        typing.Optional[ExternalProcessorInformation],
        FieldMetadata(alias="ExternalProcessorInformation"),
        pydantic.Field(alias="ExternalProcessorInformation"),
    ] = None
    fee_amount: typing_extensions.Annotated[
        typing.Optional[FeeAmount], FieldMetadata(alias="FeeAmount"), pydantic.Field(alias="FeeAmount")
    ] = None
    gateway_trans_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="GatewayTransId"),
        pydantic.Field(alias="GatewayTransId", description="Internal identifier used for processing."),
    ] = None
    invoice_data: typing_extensions.Annotated[
        typing.Optional[BillData], FieldMetadata(alias="invoiceData"), pydantic.Field(alias="invoiceData")
    ] = None
    method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Method"),
        pydantic.Field(alias="Method", description="Payment method used: card, ach, or wallet."),
    ] = None
    net_amount: typing_extensions.Annotated[
        typing.Optional[Netamountnullable],
        FieldMetadata(alias="NetAmount"),
        pydantic.Field(alias="NetAmount", description="Net amount paid."),
    ] = None
    operation: typing_extensions.Annotated[
        typing.Optional[Operation], FieldMetadata(alias="Operation"), pydantic.Field(alias="Operation")
    ] = None
    order_id: typing_extensions.Annotated[
        typing.Optional[OrderId], FieldMetadata(alias="OrderId"), pydantic.Field(alias="OrderId")
    ] = None
    org_id: typing_extensions.Annotated[
        typing.Optional[Orgid],
        FieldMetadata(alias="OrgId"),
        pydantic.Field(alias="OrgId", description="ID of immediate parent organization."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    payment_data: typing_extensions.Annotated[
        typing.Optional[QueryPaymentData], FieldMetadata(alias="PaymentData"), pydantic.Field(alias="PaymentData")
    ] = None
    payment_trans_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentTransId"),
        pydantic.Field(alias="PaymentTransId", description="Unique Transaction ID."),
    ] = None
    payor_id: typing_extensions.Annotated[
        typing.Optional[PayorId], FieldMetadata(alias="PayorId"), pydantic.Field(alias="PayorId")
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="Paypoint's DBA name."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[Entrypointfield],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="Paypoint's entryname."),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="PaypointId"),
        pydantic.Field(alias="PaypointId", description="InternalId for paypoint."),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="Paypoint's legal name."),
    ] = None
    pending_fee_amount: typing_extensions.Annotated[
        typing.Optional[PendingFeeAmount],
        FieldMetadata(alias="PendingFeeAmount"),
        pydantic.Field(alias="PendingFeeAmount"),
    ] = None
    refund_id: typing_extensions.Annotated[
        typing.Optional[RefundId], FieldMetadata(alias="RefundId"), pydantic.Field(alias="RefundId")
    ] = None
    response_data: typing_extensions.Annotated[
        typing.Optional[QueryResponseData], FieldMetadata(alias="ResponseData"), pydantic.Field(alias="ResponseData")
    ] = None
    returned_id: typing_extensions.Annotated[
        typing.Optional[ReturnedId], FieldMetadata(alias="ReturnedId"), pydantic.Field(alias="ReturnedId")
    ] = None
    schedule_reference: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ScheduleReference"),
        pydantic.Field(
            alias="ScheduleReference", description="Reference to the subscription that originated the transaction."
        ),
    ] = None
    settlement_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="SettlementStatus"),
        pydantic.Field(
            alias="SettlementStatus",
            description="Settlement status for transaction. See [the docs](/developers/references/money-in-statuses#payment-funding-status) for a full reference.",
        ),
    ] = None
    source: typing_extensions.Annotated[
        typing.Optional[Source], FieldMetadata(alias="Source"), pydantic.Field(alias="Source")
    ] = None
    split_funding_instructions: typing_extensions.Annotated[
        typing.Optional[SplitFunding],
        FieldMetadata(alias="splitFundingInstructions"),
        pydantic.Field(alias="splitFundingInstructions"),
    ] = None
    total_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="TotalAmount"),
        pydantic.Field(
            alias="TotalAmount", description="Transaction total amount (including service fee or sub-charge)"
        ),
    ] = None
    transaction_events: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryTransactionEvents]],
        FieldMetadata(alias="TransactionEvents"),
        pydantic.Field(alias="TransactionEvents", description="Events associated with this transaction."),
    ] = None
    transaction_time: typing_extensions.Annotated[
        typing.Optional[DatetimeNullable],
        FieldMetadata(alias="TransactionTime"),
        pydantic.Field(alias="TransactionTime", description="Transaction date and time, in UTC."),
    ] = None
    trans_additional_data: typing_extensions.Annotated[
        typing.Optional[typing.Any],
        FieldMetadata(alias="TransAdditionalData"),
        pydantic.Field(alias="TransAdditionalData"),
    ] = None
    trans_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="TransStatus"),
        pydantic.Field(
            alias="TransStatus",
            description="Status of transaction. See [the docs](/developers/references/money-in-statuses#money-in-transaction-status) for a full reference.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.page_identifier import PageIdentifier


class CheckCaptureResponse(UniversalBaseModel):
    """
    Response model for check capture processing.
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique ID for the check capture, to be used with the /api/MoneyIn/getpaid endpoint.
    """

    success: bool = pydantic.Field()
    """
    Indicates whether the check processing was successful.
    """

    process_date: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="processDate"),
        pydantic.Field(
            alias="processDate", description="The date and time when the check was processed (ISO 8601 format)."
        ),
    ]
    ocr_micr: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrMicr"),
        pydantic.Field(
            alias="ocrMicr",
            description="The OCR-extracted MICR (Magnetic Ink Character Recognition) line from the check.",
        ),
    ] = None
    ocr_micr_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrMicrStatus"),
        pydantic.Field(alias="ocrMicrStatus", description="Status of the MICR extraction process."),
    ] = None
    ocr_micr_confidence: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrMicrConfidence"),
        pydantic.Field(alias="ocrMicrConfidence", description="Confidence score for the MICR extraction (0 to 100)."),
    ] = None
    ocr_account_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrAccountNumber"),
        pydantic.Field(alias="ocrAccountNumber", description="The bank account number extracted from the check."),
    ] = None
    ocr_routing_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrRoutingNumber"),
        pydantic.Field(alias="ocrRoutingNumber", description="The bank routing number extracted from the check."),
    ] = None
    ocr_check_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrCheckNumber"),
        pydantic.Field(alias="ocrCheckNumber", description="The check number extracted from the check."),
    ] = None
    ocr_check_tran_code: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrCheckTranCode"),
        pydantic.Field(alias="ocrCheckTranCode", description="The transaction code extracted from the check."),
    ] = None
    ocr_amount: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrAmount"),
        pydantic.Field(alias="ocrAmount", description="The amount extracted via OCR from the check."),
    ] = None
    ocr_amount_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrAmountStatus"),
        pydantic.Field(alias="ocrAmountStatus", description="Status of the amount extraction process."),
    ] = None
    ocr_amount_confidence: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ocrAmountConfidence"),
        pydantic.Field(
            alias="ocrAmountConfidence", description="Confidence score for the amount extraction (0 to 100)."
        ),
    ] = None
    amount_discrepancy_detected: typing_extensions.Annotated[
        bool,
        FieldMetadata(alias="amountDiscrepancyDetected"),
        pydantic.Field(
            alias="amountDiscrepancyDetected",
            description="Flag indicating whether there's a discrepancy between the provided amount and the OCR-detected amount.",
        ),
    ]
    endorsement_detected: typing_extensions.Annotated[
        bool,
        FieldMetadata(alias="endorsementDetected"),
        pydantic.Field(
            alias="endorsementDetected", description="Flag indicating whether an endorsement was detected on the check."
        ),
    ]
    errors: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of error messages that occurred during processing.
    """

    messages: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of informational messages about the processing.
    """

    car_lar_match_confidence: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="carLarMatchConfidence"),
        pydantic.Field(
            alias="carLarMatchConfidence",
            description="Confidence score for the match between Courtesy Amount Recognition (CAR) and Legal Amount Recognition (LAR).",
        ),
    ] = None
    car_lar_match_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="carLarMatchStatus"),
        pydantic.Field(alias="carLarMatchStatus", description="Status of the CAR/LAR match."),
    ] = None
    front_image: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="frontImage"),
        pydantic.Field(alias="frontImage", description="Processed front image of the check (Base64-encoded)."),
    ] = None
    rear_image: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="rearImage"),
        pydantic.Field(alias="rearImage", description="Processed rear image of the check (Base64-encoded)."),
    ] = None
    check_type: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="checkType"),
        pydantic.Field(
            alias="checkType",
            description="Identifier for the type of check.\nPersonal = 1\nBusiness = 2\nOnly personal checks are supported for check capture.",
        ),
    ]
    reference_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="referenceNumber"),
        pydantic.Field(alias="referenceNumber", description="Reference number for the transaction."),
    ] = None
    page_identifier: typing_extensions.Annotated[
        typing.Optional[PageIdentifier], FieldMetadata(alias="pageIdentifier"), pydantic.Field(alias="pageIdentifier")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .additional_data import AdditionalData
from .billing_data_response import BillingDataResponse
from .contacts import Contacts
from .created_at import CreatedAt
from .dbaname import Dbaname
from .ein import Ein
from .email import Email
from .enrollment_status import EnrollmentStatus
from .entrypointfield import Entrypointfield
from .internal_reference_id import InternalReferenceId
from .last_modified import LastModified
from .legalname import Legalname
from .location_code import LocationCode
from .mcc import Mcc
from .org_parent_name import OrgParentName
from .payee_name import PayeeName
from .remitaddress_1 import Remitaddress1
from .remitaddress_2 import Remitaddress2
from .remitcity import Remitcity
from .remitcountry import Remitcountry
from .remitstate import Remitstate
from .remitzip import Remitzip
from .vendor_number import VendorNumber
from .vendor_summary import VendorSummary
from .vendorstatus import Vendorstatus


class AssociatedVendor(UniversalBaseModel):
    vendor_number: typing_extensions.Annotated[
        typing.Optional[VendorNumber], FieldMetadata(alias="VendorNumber"), pydantic.Field(alias="VendorNumber")
    ] = None
    name_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Name1"),
        pydantic.Field(alias="Name1", description="Primary name for vendor."),
    ] = None
    name_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Name2"),
        pydantic.Field(alias="Name2", description="Secondary name for vendor."),
    ] = None
    ein: typing_extensions.Annotated[typing.Optional[Ein], FieldMetadata(alias="EIN"), pydantic.Field(alias="EIN")] = (
        None
    )
    phone: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Phone"),
        pydantic.Field(alias="Phone", description="Vendor's phone number."),
    ] = None
    email: typing_extensions.Annotated[
        typing.Optional[Email],
        FieldMetadata(alias="Email"),
        pydantic.Field(alias="Email", description="Vendor's email address."),
    ] = None
    address_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Address1"),
        pydantic.Field(alias="Address1", description="Vendor's address."),
    ] = None
    address_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Address2"),
        pydantic.Field(alias="Address2", description="Additional line for vendor's address."),
    ] = None
    city: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="City"), pydantic.Field(alias="City", description="Vendor's city.")
    ] = None
    state: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="State"), pydantic.Field(alias="State", description="Vendor's state.")
    ] = None
    zip: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Zip"),
        pydantic.Field(alias="Zip", description="Vendor's postal code."),
    ] = None
    country: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Country"),
        pydantic.Field(alias="Country", description="Vendor's country."),
    ] = None
    mcc: typing_extensions.Annotated[typing.Optional[Mcc], FieldMetadata(alias="Mcc"), pydantic.Field(alias="Mcc")] = (
        None
    )
    location_code: typing_extensions.Annotated[
        typing.Optional[LocationCode], FieldMetadata(alias="LocationCode"), pydantic.Field(alias="LocationCode")
    ] = None
    contacts: typing_extensions.Annotated[
        typing.Optional[typing.List[Contacts]],
        FieldMetadata(alias="Contacts"),
        pydantic.Field(alias="Contacts", description="Array of objects describing the vendor's contacts."),
    ] = None
    billing_data: typing_extensions.Annotated[
        typing.Optional[BillingDataResponse], FieldMetadata(alias="BillingData"), pydantic.Field(alias="BillingData")
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="PaymentMethod"), pydantic.Field(alias="PaymentMethod")
    ] = None
    vendor_status: typing_extensions.Annotated[
        typing.Optional[Vendorstatus], FieldMetadata(alias="VendorStatus"), pydantic.Field(alias="VendorStatus")
    ] = None
    vendor_id: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="VendorId"), pydantic.Field(alias="VendorId")
    ] = None
    enrollment_status: typing_extensions.Annotated[
        typing.Optional[EnrollmentStatus],
        FieldMetadata(alias="EnrollmentStatus"),
        pydantic.Field(alias="EnrollmentStatus"),
    ] = None
    summary: typing_extensions.Annotated[
        typing.Optional[VendorSummary], FieldMetadata(alias="Summary"), pydantic.Field(alias="Summary")
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="The paypoint's legal name."),
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="The paypoint's DBA name."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[Entrypointfield],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="Paypoint's entryname."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    created_date: typing_extensions.Annotated[
        typing.Optional[CreatedAt], FieldMetadata(alias="CreatedDate"), pydantic.Field(alias="CreatedDate")
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[LastModified], FieldMetadata(alias="LastUpdated"), pydantic.Field(alias="LastUpdated")
    ] = None
    remit_address_1: typing_extensions.Annotated[
        typing.Optional[Remitaddress1], FieldMetadata(alias="remitAddress1"), pydantic.Field(alias="remitAddress1")
    ] = None
    remit_address_2: typing_extensions.Annotated[
        typing.Optional[Remitaddress2], FieldMetadata(alias="remitAddress2"), pydantic.Field(alias="remitAddress2")
    ] = None
    remit_city: typing_extensions.Annotated[
        typing.Optional[Remitcity], FieldMetadata(alias="remitCity"), pydantic.Field(alias="remitCity")
    ] = None
    remit_state: typing_extensions.Annotated[
        typing.Optional[Remitstate], FieldMetadata(alias="remitState"), pydantic.Field(alias="remitState")
    ] = None
    remit_zip: typing_extensions.Annotated[
        typing.Optional[Remitzip], FieldMetadata(alias="remitZip"), pydantic.Field(alias="remitZip")
    ] = None
    remit_country: typing_extensions.Annotated[
        typing.Optional[Remitcountry], FieldMetadata(alias="remitCountry"), pydantic.Field(alias="remitCountry")
    ] = None
    payee_name_1: typing_extensions.Annotated[
        typing.Optional[PayeeName], FieldMetadata(alias="payeeName1"), pydantic.Field(alias="payeeName1")
    ] = None
    payee_name_2: typing_extensions.Annotated[
        typing.Optional[PayeeName], FieldMetadata(alias="payeeName2"), pydantic.Field(alias="payeeName2")
    ] = None
    custom_field_1: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="customField1"), pydantic.Field(alias="customField1")
    ] = None
    custom_field_2: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="customField2"), pydantic.Field(alias="customField2")
    ] = None
    customer_vendor_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customerVendorAccount"),
        pydantic.Field(alias="customerVendorAccount"),
    ] = None
    internal_reference_id: typing_extensions.Annotated[
        typing.Optional[InternalReferenceId],
        FieldMetadata(alias="InternalReferenceId"),
        pydantic.Field(alias="InternalReferenceId"),
    ] = None
    additional_data: typing_extensions.Annotated[
        typing.Optional[AdditionalData], FieldMetadata(alias="additionalData"), pydantic.Field(alias="additionalData")
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="externalPaypointID"), pydantic.Field(alias="externalPaypointID")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.additional_data_map import AdditionalDataMap
from ...types.contacts import Contacts
from ...types.email import Email
from ...types.internal_reference_id import InternalReferenceId
from ...types.location_code import LocationCode
from ...types.mcc import Mcc
from ...types.payee_name import PayeeName
from ...types.remitaddress_1 import Remitaddress1
from ...types.remitaddress_2 import Remitaddress2
from ...types.remitcity import Remitcity
from ...types.remitcountry import Remitcountry
from ...types.remitstate import Remitstate
from ...types.remitzip import Remitzip
from ...types.vendor_number import VendorNumber
from ...types.vendor_response_billing_data import VendorResponseBillingData
from ...types.vendor_response_stored_method import VendorResponseStoredMethod
from ...types.vendor_response_summary import VendorResponseSummary
from ...types.vendorid import Vendorid
from ...types.vendorstatus import Vendorstatus


class GetMethodResponseResponseDataVendorsItem(UniversalBaseModel):
    additional_data: typing_extensions.Annotated[
        typing.Optional[AdditionalDataMap],
        FieldMetadata(alias="additionalData"),
        pydantic.Field(alias="additionalData", description="Additional data for vendor"),
    ] = None
    address_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="address1"),
        pydantic.Field(alias="address1", description="Vendor's address"),
    ] = None
    address_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="address2"),
        pydantic.Field(alias="address2", description="Additional line for vendor's address"),
    ] = None
    billing_data: typing_extensions.Annotated[
        typing.Optional[VendorResponseBillingData],
        FieldMetadata(alias="billingData"),
        pydantic.Field(alias="billingData", description="Object containing vendor's bank information"),
    ] = None
    city: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's city
    """

    contacts: typing.Optional[typing.List[Contacts]] = pydantic.Field(default=None)
    """
    Array of objects describing the vendor's contacts
    """

    country: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's country
    """

    created_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="createdDate"),
        pydantic.Field(alias="createdDate", description="Date when vendor was created"),
    ] = None
    custom_field_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customField1"),
        pydantic.Field(alias="customField1", description="Custom field 1 for vendor"),
    ] = None
    custom_field_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customField2"),
        pydantic.Field(alias="customField2", description="Custom field 2 for vendor"),
    ] = None
    customer_vendor_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customerVendorAccount"),
        pydantic.Field(alias="customerVendorAccount", description="Account number of paypoint in the vendor's side"),
    ] = None
    ein: typing.Optional[str] = pydantic.Field(default=None)
    """
    EIN/Tax ID for vendor. In responses, this field is masked.
    """

    email: typing.Optional[Email] = pydantic.Field(default=None)
    """
    Vendor's email address
    """

    enrollment_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="enrollmentStatus"),
        pydantic.Field(alias="enrollmentStatus", description="Vendor enrollment status"),
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID", description="External paypoint identifier"),
    ] = None
    internal_reference_id: typing_extensions.Annotated[
        typing.Optional[InternalReferenceId],
        FieldMetadata(alias="internalReferenceId"),
        pydantic.Field(alias="internalReferenceId", description="Internal reference ID for vendor"),
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="lastUpdated"),
        pydantic.Field(alias="lastUpdated", description="Date when vendor was last updated"),
    ] = None
    location_code: typing_extensions.Annotated[
        typing.Optional[LocationCode],
        FieldMetadata(alias="locationCode"),
        pydantic.Field(alias="locationCode", description="Location code for vendor"),
    ] = None
    mcc: typing.Optional[Mcc] = pydantic.Field(default=None)
    """
    Merchant category code
    """

    name_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="name1"),
        pydantic.Field(alias="name1", description="Primary name for vendor"),
    ] = None
    name_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="name2"),
        pydantic.Field(alias="name2", description="Secondary name for vendor"),
    ] = None
    parent_org_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="parentOrgId"),
        pydantic.Field(alias="parentOrgId", description="ID of the parent organization"),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="parentOrgName"),
        pydantic.Field(alias="parentOrgName", description="Name of the parent organization"),
    ] = None
    payee_name_1: typing_extensions.Annotated[
        typing.Optional[PayeeName],
        FieldMetadata(alias="payeeName1"),
        pydantic.Field(alias="payeeName1", description="Primary payee name"),
    ] = None
    payee_name_2: typing_extensions.Annotated[
        typing.Optional[PayeeName],
        FieldMetadata(alias="payeeName2"),
        pydantic.Field(alias="payeeName2", description="Secondary payee name"),
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paymentMethod"),
        pydantic.Field(alias="paymentMethod", description="Preferred payment method for vendor"),
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointDbaname"),
        pydantic.Field(alias="paypointDbaname", description="DBA name of the paypoint"),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointEntryname"),
        pydantic.Field(alias="paypointEntryname", description="Entry name of the paypoint"),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointId"),
        pydantic.Field(alias="paypointId", description="Paypoint ID"),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="paypointLegalname"),
        pydantic.Field(alias="paypointLegalname", description="Legal name of the paypoint"),
    ] = None
    phone: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's phone number
    """

    remit_address_1: typing_extensions.Annotated[
        typing.Optional[Remitaddress1],
        FieldMetadata(alias="remitAddress1"),
        pydantic.Field(alias="remitAddress1", description="Remittance address line 1"),
    ] = None
    remit_address_2: typing_extensions.Annotated[
        typing.Optional[Remitaddress2],
        FieldMetadata(alias="remitAddress2"),
        pydantic.Field(alias="remitAddress2", description="Remittance address line 2"),
    ] = None
    remit_city: typing_extensions.Annotated[
        typing.Optional[Remitcity],
        FieldMetadata(alias="remitCity"),
        pydantic.Field(alias="remitCity", description="Remittance city"),
    ] = None
    remit_country: typing_extensions.Annotated[
        typing.Optional[Remitcountry],
        FieldMetadata(alias="remitCountry"),
        pydantic.Field(alias="remitCountry", description="Remittance country"),
    ] = None
    remit_email: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="remitEmail"),
        pydantic.Field(alias="remitEmail", description="Email address for remittance"),
    ] = None
    remit_state: typing_extensions.Annotated[
        typing.Optional[Remitstate],
        FieldMetadata(alias="remitState"),
        pydantic.Field(alias="remitState", description="Remittance state"),
    ] = None
    remit_zip: typing_extensions.Annotated[
        typing.Optional[Remitzip],
        FieldMetadata(alias="remitZip"),
        pydantic.Field(alias="remitZip", description="Remittance ZIP code"),
    ] = None
    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's state
    """

    stored_methods: typing_extensions.Annotated[
        typing.Optional[typing.List[VendorResponseStoredMethod]],
        FieldMetadata(alias="storedMethods"),
        pydantic.Field(alias="storedMethods", description="Array of stored payment methods for vendor"),
    ] = None
    summary: typing.Optional[VendorResponseSummary] = pydantic.Field(default=None)
    """
    Vendor bill summary statistics
    """

    vendor_id: typing_extensions.Annotated[
        typing.Optional[Vendorid],
        FieldMetadata(alias="vendorId"),
        pydantic.Field(alias="vendorId", description="The unique numeric ID assigned to the vendor in Payabli"),
    ] = None
    vendor_number: typing_extensions.Annotated[
        typing.Optional[VendorNumber],
        FieldMetadata(alias="vendorNumber"),
        pydantic.Field(alias="vendorNumber", description="Custom vendor number assigned by the business"),
    ] = None
    vendor_status: typing_extensions.Annotated[
        typing.Optional[Vendorstatus],
        FieldMetadata(alias="vendorStatus"),
        pydantic.Field(alias="vendorStatus", description="Status code for the vendor"),
    ] = None
    zip: typing.Optional[str] = pydantic.Field(default=None)
    """
    Vendor's ZIP code
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .ach_absorb_section import AchAbsorbSection
from .ach_acceptance_element import AchAcceptanceElement
from .ach_fee_section import AchFeeSection
from .ach_pass_through_section import AchPassThroughSection
from .template_element import TemplateElement
from .visible import Visible


class AchService(UniversalBaseModel):
    ach_absorb: typing_extensions.Annotated[
        typing.Optional[AchAbsorbSection], FieldMetadata(alias="achAbsorb"), pydantic.Field(alias="achAbsorb")
    ] = None
    ach_absorb_high_pay_range: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="achAbsorb_highPayRange"),
        pydantic.Field(alias="achAbsorb_highPayRange"),
    ] = None
    ach_absorb_low_pay_range: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="achAbsorb_lowPayRange"),
        pydantic.Field(alias="achAbsorb_lowPayRange"),
    ] = None
    ach_acceptance: typing_extensions.Annotated[
        typing.Optional[AchAcceptanceElement],
        FieldMetadata(alias="achAcceptance"),
        pydantic.Field(alias="achAcceptance"),
    ] = None
    ach_fees: typing_extensions.Annotated[
        typing.Optional[AchFeeSection], FieldMetadata(alias="achFees"), pydantic.Field(alias="achFees")
    ] = None
    ach_pass_high_pay_range: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="achPass_highPayRange"),
        pydantic.Field(alias="achPass_highPayRange"),
    ] = None
    ach_pass_low_pay_range: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="achPass_lowPayRange"),
        pydantic.Field(alias="achPass_lowPayRange"),
    ] = None
    ach_pass_through: typing_extensions.Annotated[
        typing.Optional[AchPassThroughSection],
        FieldMetadata(alias="achPassThrough"),
        pydantic.Field(alias="achPassThrough"),
    ] = None
    batch_cutoff_time: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="batchCutoffTime"),
        pydantic.Field(
            alias="batchCutoffTime",
            description="Controls how to present the `batchCutoffTime` field on the application. If this field isn't sent, batch cut off time defaults to 5 ET.",
        ),
    ] = None
    discount_frequency: typing_extensions.Annotated[
        typing.Optional[TemplateElement],
        FieldMetadata(alias="discountFrequency"),
        pydantic.Field(alias="discountFrequency"),
    ] = None
    funding_rollup: typing_extensions.Annotated[
        typing.Optional[TemplateElement], FieldMetadata(alias="fundingRollup"), pydantic.Field(alias="fundingRollup")
    ] = None
    gateway: typing.Optional[TemplateElement] = None
    pdf_template_id: typing_extensions.Annotated[
        typing.Optional[TemplateElement], FieldMetadata(alias="pdfTemplateId"), pydantic.Field(alias="pdfTemplateId")
    ] = None
    pricing_plan: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="pricingPlan"), pydantic.Field(alias="pricingPlan")
    ] = None
    pricing_type: typing_extensions.Annotated[
        typing.Optional[TemplateElement], FieldMetadata(alias="pricingType"), pydantic.Field(alias="pricingType")
    ] = None
    processor: typing.Optional[TemplateElement] = None
    provider: typing.Optional[TemplateElement] = None
    tier_name: typing_extensions.Annotated[
        typing.Optional[TemplateElement], FieldMetadata(alias="tierName"), pydantic.Field(alias="tierName")
    ] = None
    visible: typing.Optional[Visible] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class StatBasicExtendedQueryRecord(UniversalBaseModel):
    stat_x: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="statX"),
        pydantic.Field(
            alias="statX", description="The time window based on the mode and frequency used for the query."
        ),
    ]
    out_customers: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outCustomers"),
        pydantic.Field(alias="outCustomers", description="Number of active vendors."),
    ]
    out_new_customers: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outNewCustomers"),
        pydantic.Field(alias="outNewCustomers", description="Number of new vendors."),
    ]
    out_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outTransactions"),
        pydantic.Field(alias="outTransactions", description="Outbound (payout) transactions count."),
    ]
    out_subscriptions_paid: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outSubscriptionsPaid"),
        pydantic.Field(alias="outSubscriptionsPaid", description="Recurring outbound (payout) transactions count."),
    ]
    out_card_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outCardTransactions"),
        pydantic.Field(alias="outCardTransactions", description="Outbound (payout) pCard transactions count."),
    ]
    out_v_card_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outVCardTransactions"),
        pydantic.Field(alias="outVCardTransactions", description="Outbound (payout) vCard transactions count."),
    ]
    out_ach_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outACHTransactions"),
        pydantic.Field(alias="outACHTransactions", description="Outbound (payout) ACH transactions count."),
    ]
    out_check_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outCheckTransactions"),
        pydantic.Field(alias="outCheckTransactions", description="Outbound (payout) check transactions count."),
    ]
    out_pending_method_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="outPendingMethodTransactions"),
        pydantic.Field(
            alias="outPendingMethodTransactions", description="Outbound (payout) Managed Payables transactions count."
        ),
    ]
    out_transactions_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="outTransactionsVolume"),
        pydantic.Field(alias="outTransactionsVolume", description="Outbound (payout) volume."),
    ]
    out_subscriptions_paid_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="outSubscriptionsPaidVolume"),
        pydantic.Field(alias="outSubscriptionsPaidVolume", description="Recurring outbound (payout) volume."),
    ]
    out_card_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="outCardVolume"),
        pydantic.Field(alias="outCardVolume", description="Outbound (payout) pCard transactions volume."),
    ]
    out_v_card_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="outVCardVolume"),
        pydantic.Field(alias="outVCardVolume", description="Outbound (payout) vCard transactions volume."),
    ]
    out_ach_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="outACHVolume"),
        pydantic.Field(alias="outACHVolume", description="Outbound (payout) ACH transactions volume."),
    ]
    out_check_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="outCheckVolume"),
        pydantic.Field(alias="outCheckVolume", description="Outbound (payout) check transactions volume."),
    ]
    out_pending_method_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="outPendingMethodVolume"),
        pydantic.Field(alias="outPendingMethodVolume", description="Outbound (payout) Managed Payables volume."),
    ]
    in_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inTransactions"),
        pydantic.Field(alias="inTransactions", description="Inbound transactions count."),
    ]
    in_subscriptions_paid: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inSubscriptionsPaid"),
        pydantic.Field(alias="inSubscriptionsPaid", description="Inbound recurring transactions count."),
    ]
    in_customers: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inCustomers"),
        pydantic.Field(alias="inCustomers", description="Number of active customers."),
    ]
    in_new_customers: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inNewCustomers"),
        pydantic.Field(alias="inNewCustomers", description="Number of new customers."),
    ]
    in_card_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inCardTransactions"),
        pydantic.Field(alias="inCardTransactions", description="Inbound card transactions count."),
    ]
    in_ach_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inACHTransactions"),
        pydantic.Field(alias="inACHTransactions", description="Inbound ACH transactions count."),
    ]
    in_check_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inCheckTransactions"),
        pydantic.Field(alias="inCheckTransactions", description="Inbound check transactions count."),
    ]
    in_cash_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inCashTransactions"),
        pydantic.Field(alias="inCashTransactions", description="Inbound cash transactions count."),
    ]
    in_wallet_transactions: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inWalletTransactions"),
        pydantic.Field(alias="inWalletTransactions", description="Inbound wallet transactions count."),
    ]
    in_card_charge_backs: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inCardChargeBacks"),
        pydantic.Field(alias="inCardChargeBacks", description="Inbound card chargebacks and returns count."),
    ]
    in_ach_returns: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="inACHReturns"),
        pydantic.Field(alias="inACHReturns", description="Inbound ACH returns count."),
    ]
    in_transactions_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inTransactionsVolume"),
        pydantic.Field(alias="inTransactionsVolume", description="Inbound volume."),
    ]
    in_subscriptions_paid_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inSubscriptionsPaidVolume"),
        pydantic.Field(alias="inSubscriptionsPaidVolume", description="Inbound recurring payments volume."),
    ]
    in_card_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inCardVolume"),
        pydantic.Field(alias="inCardVolume", description="Inbound card volume."),
    ]
    in_ach_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inACHVolume"),
        pydantic.Field(alias="inACHVolume", description="Inbound ACH volume."),
    ]
    in_check_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inCheckVolume"),
        pydantic.Field(alias="inCheckVolume", description="Inbound check volume."),
    ]
    in_cash_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inCashVolume"),
        pydantic.Field(alias="inCashVolume", description="Inbound cash volume recognized."),
    ]
    in_wallet_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inWalletVolume"),
        pydantic.Field(alias="inWalletVolume", description="Inbound wallet transactions."),
    ]
    in_card_charge_back_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inCardChargeBackVolume"),
        pydantic.Field(alias="inCardChargeBackVolume", description="Inbound Card chargebacks and returns volume."),
    ]
    in_ach_returns_volume: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="inACHReturnsVolume"),
        pydantic.Field(alias="inACHReturnsVolume", description="Inbound ACH returns volume."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
